| summary.modeLLtest | R Documentation |
summary methods for objects returned by cvdm,
cvll, cvlldiff, and cvmf.
They collect the test results stored in the object into a list that can
be printed or used programmatically. No models are re-estimated.
## S3 method for class 'cvdm'
summary(object, ...)
## S3 method for class 'summary.cvdm'
print(x, digits = max(3, getOption("digits") - 3), ...)
## S3 method for class 'cvll'
summary(object, ...)
## S3 method for class 'summary.cvll'
print(x, digits = max(3, getOption("digits") - 3), ...)
## S3 method for class 'cvlldiff'
summary(object, ...)
## S3 method for class 'summary.cvlldiff'
print(x, digits = max(3, getOption("digits") - 3), ...)
## S3 method for class 'cvmf'
summary(object, ...)
## S3 method for class 'summary.cvmf'
print(x, digits = max(3, getOption("digits") - 3), ...)
object |
an object of class |
... |
further arguments passed to or from other methods. |
x |
an object returned by one of the |
digits |
the number of significant digits to use when printing. |
An object of class summary.cvdm, summary.cvll,
summary.cvlldiff, or summary.cvmf. Each is a list that
contains the call (except for cvlldiff), the preferred
method (best) where relevant, and a table of the test
results. summary.cvmf also contains plm_table and
irr_table, the coefficient tables for the partial likelihood
and robust estimators.
cvdm_object, cvll_object,
cvlldiff_object, cvmf_object
set.seed(123456)
X <- runif(200, -1, 1)
Y <- 0.2 + 0.5 * X + rnorm(200)
obj_cvdm <- cvdm(Y ~ X, data.frame(cbind(Y, X)),
method1 = "OLS", method2 = "MR")
summary(obj_cvdm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.